
.org-mode #logo { 
        float: right;
        clear: right;
        margin-right: 2px;
        margin-top: -8em;
        display: compact;
 }

.org-mode header hgroup h1 {
     background: #ffeedd 
     url(http://dyne.org/pics/dynebggrl2r.png) repeat-y;
     color: #222222;
     overflow: hidden;             /* don't crowd the menu */
     border: 0px;
     border-bottom: 2px dotted #EECC99;
     font-style: italic;
     font-size: 28px;
     padding: 0.5em;
     margin-bottom: 0;
     margin-left: 0;
     white-space: nowrap;
     }

.org-mode .todo   { color: red; }
.org-mode .done   { color: green; }
.org-mode .tag    { background-color: #add8e6; font-weight:normal }
.org-mode .target { }
.org-mode .timestamp { color: #bebebe; }
.org-mode .timestamp-kwd { color: #5f9ea0; }
.org-mode p.verse { margin-left: 3% }
.org-mode pre {
      border: 1pt solid #AEBDCC;
      background-color: #F3F5F7;
      padding: 5pt;
      font-family: monospace, courier;
      font-size: 90%
      overflow: auto;
      }
.org-mode table { border-collapse: collapse; }
.org-mode td, .org-mode th { vertical-align: top; }
.org-mode dt { font-weight: bold; }
.org-mode div.figure { padding: 0.5em; }
.org-mode div.figure p { text-align: center; }
.org-mode .linenr { font-size:smaller }
.org-mode .code-highlighted {background-color:#ffff00;}
.org-mode .org-info-js_info-navigation { border-style:none; }
.org-mode #org-info-js_console-label { font-size:10px; font-weight:bold;
                             white-space:nowrap; }
.org-mode .org-info-js_search-highlight {background-color:#ffff00; color:#000000;
                                font-weight:bold; }

.org-mode .outline-1 { text-align: center; }
.org-mode .outline-2 { margin-left: 10em; margin-right: 1em; }
.org-mode .outline-3 { margin-left: 1em; }

.org-mode #postamble { opacity: 0.66; 
             font-size: 0.66em;
             text-align: right;
             display: none;
             float: right;
             clear: right;
             width: 25em;
             margin-right: 1.5em;
             }


.org-mode #menu { 
                  position: fixed;
                  }


.org-mode #document-types { 
                  width: 15em;
                  float: left;
                  clear: left;
                  margin-left: 0.5em;
                  margin-right: 3em;
                  display: compact;
                  font-size: 0.88em;
                  text-align: left;
                  }

/* TOC on top of sidebar */
.org-mode #table-of-contents { 
                     width: 15em;
                     float: left;
                     clear: left;
                     margin-left: 0.5em;
                     margin-right: 3em;
                     margin-bottom: 0.5em;
                     display: compact;
                     font-size: 0.88em;
                     }

.org-mode #table-of-contents h2 { font-size: 1em; }
.org-mode #table-of-contents ul { list-style: none; margin: 0em 0em; padding: 0; }
.org-mode #table-of-contents li { margin: 0; padding: 0 0 0 0.5em; }

/* first section is sidebar 
.org-mode #outline-container-1 { 
                       width: 15em;
                       float: left;
                       clear: left;
                       margin-right: 3em
                       display: compact;
                       font-size: 0.78em;
                       } */