.org-mode pre.src { 
        color: #F8F8F8;
        background-color: #141414;
      }
      .org-better-fringes-bitmap {
        /* better-fringes-bitmap */
        color: #f0e68c;
      }
      .org-better-fringes-important-bitmap {
        /* better-fringes-important-bitmap */
        color: #ff0000;
      }
      .org-blue {
        /* blue */
        color: #0000ff;
      }
      .org-bold {
        /* bold */
        font-weight: bold;
      }
      .org-bold-italic {
        /* bold-italic */
        font-weight: bold;
        font-style: italic;
      }
      .org-bookmark-menu-heading {
        /* bookmark-menu-heading */
        color: #9B703F;
      }
      .org-border {
        /* border */
        background-color: #000000;
      }
      .org-border-glyph {
      }
      .org-buffer-menu-buffer {
        /* buffer-menu-buffer */
        font-weight: bold;
      }
      .org-buffers-tab {
        /* buffers-tab */
        color: #CACACA;
        background-color: #141414;
      }
      .org-builtin {
        /* font-lock-builtin-face */
        color: #CACACA;
      }
      .org-button {
        /* button */
        text-decoration: underline;
      }
      .org-c-nonbreakable-space {
        /* c-nonbreakable-space-face */
        color: #EE799F;
        background-color: #ff0000;
      }
      .org-calendar-today {
        /* calendar-today */
        text-decoration: underline;
      }
      .org-change-log-acknowledgement {
        /* change-log-acknowledgement */
        color: #5F5A60;
      }
      .org-change-log-conditionals {
        /* change-log-conditionals */
        color: #7587A6;
      }
      .org-change-log-date {
        /* change-log-date */
        color: #8F9D6A;
      }
      .org-change-log-email {
        /* change-log-email */
        color: #7587A6;
      }
      .org-change-log-file {
        /* change-log-file */
        color: #9B703F;
      }
      .org-change-log-function {
        /* change-log-function */
        color: #7587A6;
      }
      .org-change-log-list {
        /* change-log-list */
        color: #CDA869;
      }
      .org-change-log-name {
        /* change-log-name */
        color: #CF6A4C;
      }
      .org-comint-highlight-input {
        /* comint-highlight-input */
        font-weight: bold;
      }
      .org-comint-highlight-prompt {
        /* comint-highlight-prompt */
        color: #00ffff;
      }
      .org-comment {
        /* font-lock-comment-face */
        color: #5F5A60;
      }
      .org-comment-delimiter {
        /* font-lock-comment-delimiter-face */
        color: #5F5A60;
      }
      .org-compilation-column-number {
        /* compilation-column-number */
        color: #9B703F;
      }
      .org-compilation-error {
        /* compilation-error */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-compilation-info {
        /* compilation-info */
        color: #00ff00;
        font-weight: bold;
      }
      .org-compilation-line-number {
        /* compilation-line-number */
        color: #7587A6;
      }
      .org-compilation-warning {
        /* compilation-warning */
        color: #ffa500;
        font-weight: bold;
      }
      .org-completions-common-part {
        /* completions-common-part */
        color: #F8F8F8;
        background-color: #141414;
      }
      .org-completions-first-difference {
        /* completions-first-difference */
        font-weight: bold;
      }
      .org-constant {
        /* font-lock-constant-face */
        color: #CF6A4C;
      }
      .org-cursor {
        /* cursor */
        background-color: #A7A7A7;
      }
      .org-custom-button {
        /* custom-button-face */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-custom-button-1 {
        /* custom-button */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-custom-button-mouse {
        /* custom-button-mouse */
        color: #000000;
        background-color: #e5e5e5;
      }
      .org-custom-button-pressed {
        /* custom-button-pressed */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-custom-button-pressed-unraised {
        /* custom-button-pressed-unraised */
        color: #ee82ee;
      }
      .org-custom-button-unraised {
      }
      .org-custom-changed {
        /* custom-changed-face */
        color: #ffffff;
        background-color: #0000ff;
      }
      .org-custom-changed-1 {
        /* custom-changed */
        color: #ffffff;
        background-color: #0000ff;
      }
      .org-custom-comment {
        /* custom-comment */
        background-color: #696969;
      }
      .org-custom-comment-tag {
        /* custom-comment-tag */
        color: #cccccc;
      }
      .org-custom-documentation {
      }
      .org-custom-documentation-1 {
      }
      .org-custom-face-tag {
        /* custom-face-tag-face */
        color: #add8e6;
        font-weight: bold;
      }
      .org-custom-face-tag-1 {
        /* custom-face-tag */
        color: #add8e6;
        font-weight: bold;
      }
      .org-custom-group-tag {
        /* custom-group-tag-face */
        color: #add8e6;
        font-size: 120%;
        font-weight: bold;
      }
      .org-custom-group-tag-1 {
        /* custom-group-tag-1 */
        color: #ffc0cb;
        font-size: 120%;
        font-weight: bold;
      }
      .org-custom-group-tag-2 {
        /* custom-group-tag */
        color: #add8e6;
        font-size: 120%;
        font-weight: bold;
      }
      .org-custom-group-tag-face-1 {
        /* custom-group-tag-face-1 */
        color: #ffc0cb;
        font-size: 120%;
        font-weight: bold;
      }
      .org-custom-invalid {
        /* custom-invalid-face */
        color: #ffff00;
        background-color: #ff0000;
      }
      .org-custom-invalid-1 {
        /* custom-invalid */
        color: #ffff00;
        background-color: #ff0000;
      }
      .org-custom-link {
        /* custom-link */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-custom-modified {
        /* custom-modified-face */
        color: #ffffff;
        background-color: #0000ff;
      }
      .org-custom-modified-1 {
        /* custom-modified */
        color: #ffffff;
        background-color: #0000ff;
      }
      .org-custom-rogue {
        /* custom-rogue-face */
        color: #ffc0cb;
        background-color: #000000;
      }
      .org-custom-rogue-1 {
        /* custom-rogue */
        color: #ffc0cb;
        background-color: #000000;
      }
      .org-custom-saved {
        /* custom-saved-face */
        text-decoration: underline;
      }
      .org-custom-saved-1 {
        /* custom-saved */
        text-decoration: underline;
      }
      .org-custom-set {
        /* custom-set-face */
        color: #0000ff;
        background-color: #ffffff;
      }
      .org-custom-set-1 {
        /* custom-set */
        color: #0000ff;
        background-color: #ffffff;
      }
      .org-custom-state {
        /* custom-state-face */
        color: #32cd32;
      }
      .org-custom-state-1 {
        /* custom-state */
        color: #32cd32;
      }
      .org-custom-themed {
        /* custom-themed */
        color: #ffffff;
        background-color: #0000ff;
      }
      .org-custom-variable-button {
        /* custom-variable-button-face */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-custom-variable-button-1 {
        /* custom-variable-button */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-custom-variable-tag {
        /* custom-variable-tag-face */
        color: #add8e6;
        font-weight: bold;
      }
      .org-custom-variable-tag-1 {
        /* custom-variable-tag */
        color: #add8e6;
        font-weight: bold;
      }
      .org-custom-visibility {
        /* custom-visibility */
        color: #00ffff;
        font-size: 80%;
        text-decoration: underline;
      }
      .org-default {
        /* default */
        color: #F8F8F8;
        background-color: #141414;
      }
      .org-diary {
        /* diary */
        color: #ffff00;
      }
      .org-dired-directory {
        /* dired-directory */
        color: #9B703F;
      }
      .org-dired-flagged {
        /* dired-flagged */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-dired-header {
        /* dired-header */
        color: #9B703F;
      }
      .org-dired-ignored {
        /* dired-ignored */
        color: #b3b3b3;
      }
      .org-dired-mark {
        /* dired-mark */
        color: #CF6A4C;
      }
      .org-dired-marked {
        /* dired-marked */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-dired-perm-write {
        /* dired-perm-write */
        color: #5F5A60;
      }
      .org-dired-symlink {
        /* dired-symlink */
        color: #CDA869;
      }
      .org-dired-warning {
        /* dired-warning */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-doc {
        /* font-lock-doc-face */
        color: #8F9D6A;
      }
      .org-doc-string {
        /* font-lock-doc-string-face */
        color: #ff8c00;
      }
      .org-ediff-current-diff-a {
        /* ediff-current-diff-A */
        color: #b22222;
        background-color: #98fb98;
      }
      .org-ediff-current-diff-ancestor {
        /* ediff-current-diff-Ancestor */
        color: #000000;
        background-color: #d02090;
      }
      .org-ediff-current-diff-b {
        /* ediff-current-diff-B */
        color: #9932cc;
        background-color: #ffff00;
      }
      .org-ediff-current-diff-c {
        /* ediff-current-diff-C */
        color: #000080;
        background-color: #ffc0cb;
      }
      .org-ediff-even-diff-a {
        /* ediff-even-diff-A */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-ediff-even-diff-ancestor {
        /* ediff-even-diff-Ancestor */
        color: #ffffff;
        background-color: #bebebe;
      }
      .org-ediff-even-diff-b {
        /* ediff-even-diff-B */
        color: #ffffff;
        background-color: #bebebe;
      }
      .org-ediff-even-diff-c {
        /* ediff-even-diff-C */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-ediff-fine-diff-a {
        /* ediff-fine-diff-A */
        color: #000080;
        background-color: #87ceeb;
      }
      .org-ediff-fine-diff-ancestor {
        /* ediff-fine-diff-Ancestor */
        color: #000000;
        background-color: #00ff00;
      }
      .org-ediff-fine-diff-b {
        /* ediff-fine-diff-B */
        color: #000000;
        background-color: #00ffff;
      }
      .org-ediff-fine-diff-c {
        /* ediff-fine-diff-C */
        color: #000000;
        background-color: #40e0d0;
      }
      .org-ediff-odd-diff-a {
        /* ediff-odd-diff-A */
        color: #ffffff;
        background-color: #bebebe;
      }
      .org-ediff-odd-diff-ancestor {
        /* ediff-odd-diff-Ancestor */
        color: #00cdcd;
        background-color: #666666;
      }
      .org-ediff-odd-diff-b {
        /* ediff-odd-diff-B */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-ediff-odd-diff-c {
        /* ediff-odd-diff-C */
        color: #ffffff;
        background-color: #bebebe;
      }
      .org-escape-glyph {
        /* escape-glyph */
        color: #00ffff;
      }
      .org-file-name-shadow {
        /* file-name-shadow */
        color: #b3b3b3;
      }
      .org-fixed-pitch {
      }
      .org-fl-comment {
        /* fl-comment-face */
        color: #ffc0cb;
      }
      .org-fl-doc-string {
        /* fl-doc-string-face */
        color: #a020f0;
      }
      .org-fl-function-name {
        /* fl-function-name-face */
        color: #ff0000;
      }
      .org-fl-keyword {
        /* fl-keyword-face */
        color: #00ffff;
      }
      .org-fl-string {
        /* fl-string-face */
        color: #00ff00;
      }
      .org-fl-type {
        /* fl-type-face */
        color: #ffff00;
      }
      .org-flymake-errline {
        /* flymake-errline */
        background-color: #8b1a1a;
      }
      .org-flymake-warnline {
        /* flymake-warnline */
        background-color: #00008b;
      }
      .org-flyspell-duplicate {
        /* flyspell-duplicate */
        color: #cdad00;
        font-weight: bold;
        text-decoration: underline;
      }
      .org-flyspell-incorrect {
        /* flyspell-incorrect */
        color: #ff4500;
        font-weight: bold;
        text-decoration: underline;
      }
      .org-fringe {
        /* fringe */
        background-color: #1a1a1a;
      }
      .org-function-name {
        /* font-lock-function-name-face */
        color: #9B703F;
      }
      .org-gnus-cite-attribution {
        /* gnus-cite-attribution-face */
        font-style: italic;
      }
      .org-gnus-cite-face-1 {
        /* gnus-cite-face-1 */
        color: #00bfff;
        font-weight: bold;
      }
      .org-gnus-cite-face-10 {
        /* gnus-cite-face-10 */
        color: #9370db;
      }
      .org-gnus-cite-face-11 {
        /* gnus-cite-face-11 */
        color: #40e0d0;
      }
      .org-gnus-cite-face-2 {
        /* gnus-cite-face-2 */
        color: #00ffff;
        font-weight: bold;
      }
      .org-gnus-cite-face-3 {
        /* gnus-cite-face-3 */
        color: #ffd700;
        font-weight: bold;
      }
      .org-gnus-cite-face-4 {
        /* gnus-cite-face-4 */
        color: #ffb6c1;
      }
      .org-gnus-cite-face-5 {
        /* gnus-cite-face-5 */
        color: #98fb98;
      }
      .org-gnus-cite-face-6 {
        /* gnus-cite-face-6 */
        color: #d2691e;
        font-weight: bold;
      }
      .org-gnus-cite-face-7 {
        /* gnus-cite-face-7 */
        color: #ffa500;
      }
      .org-gnus-cite-face-8 {
        /* gnus-cite-face-8 */
        color: #ff00ff;
      }
      .org-gnus-cite-face-9 {
        /* gnus-cite-face-9 */
        color: #ee82ee;
      }
      .org-gnus-emphasis-bold {
        /* gnus-emphasis-bold */
        font-weight: bold;
      }
      .org-gnus-emphasis-bold-italic {
        /* gnus-emphasis-bold-italic */
        font-weight: bold;
        font-style: italic;
      }
      .org-gnus-emphasis-highlight-words {
        /* gnus-emphasis-highlight-words */
        color: #ffff00;
        background-color: #000000;
      }
      .org-gnus-emphasis-italic {
        /* gnus-emphasis-italic */
        font-style: italic;
      }
      .org-gnus-emphasis-underline {
        /* gnus-emphasis-underline */
        text-decoration: underline;
      }
      .org-gnus-emphasis-underline-bold {
        /* gnus-emphasis-underline-bold */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-gnus-emphasis-underline-bold-italic {
        /* gnus-emphasis-underline-bold-italic */
        font-weight: bold;
        font-style: italic;
        text-decoration: underline;
      }
      .org-gnus-emphasis-underline-italic {
        /* gnus-emphasis-underline-italic */
        font-style: italic;
        text-decoration: underline;
      }
      .org-gnus-group-mail-1 {
        /* gnus-group-mail-1 */
        color: #7fffd4;
        font-weight: bold;
      }
      .org-gnus-group-mail-1-empty {
        /* gnus-group-mail-1-empty */
        color: #7fffd4;
      }
      .org-gnus-group-mail-2 {
        /* gnus-group-mail-2 */
        color: #76eec6;
        font-weight: bold;
      }
      .org-gnus-group-mail-2-empty {
        /* gnus-group-mail-2-empty */
        color: #76eec6;
      }
      .org-gnus-group-mail-3 {
        /* gnus-group-mail-3 */
        color: #66cdaa;
        font-weight: bold;
      }
      .org-gnus-group-mail-3-empty {
        /* gnus-group-mail-3-empty */
        color: #66cdaa;
      }
      .org-gnus-group-mail-low {
        /* gnus-group-mail-low */
        color: #458b74;
        font-weight: bold;
      }
      .org-gnus-group-mail-low-empty {
        /* gnus-group-mail-low-empty */
        color: #458b74;
      }
      .org-gnus-group-news-1 {
        /* gnus-group-news-1 */
        color: #afeeee;
        font-weight: bold;
      }
      .org-gnus-group-news-1-empty {
        /* gnus-group-news-1-empty */
        color: #afeeee;
      }
      .org-gnus-group-news-2 {
        /* gnus-group-news-2 */
        color: #40e0d0;
        font-weight: bold;
      }
      .org-gnus-group-news-2-empty {
        /* gnus-group-news-2-empty */
        color: #40e0d0;
      }
      .org-gnus-group-news-3 {
        /* gnus-group-news-3 */
        font-weight: bold;
      }
      .org-gnus-group-news-3-empty {
      }
      .org-gnus-group-news-4 {
        /* gnus-group-news-4 */
        font-weight: bold;
      }
      .org-gnus-group-news-4-empty {
      }
      .org-gnus-group-news-5 {
        /* gnus-group-news-5 */
        font-weight: bold;
      }
      .org-gnus-group-news-5-empty {
      }
      .org-gnus-group-news-6 {
        /* gnus-group-news-6 */
        font-weight: bold;
      }
      .org-gnus-group-news-6-empty {
      }
      .org-gnus-group-news-low {
        /* gnus-group-news-low */
        color: #00ced1;
        font-weight: bold;
      }
      .org-gnus-group-news-low-empty {
        /* gnus-group-news-low-empty */
        color: #00ced1;
      }
      .org-gnus-header-content {
        /* gnus-header-content-face */
        color: #228b22;
        font-style: italic;
      }
      .org-gnus-header-from {
        /* gnus-header-from-face */
        color: #00ff7f;
        font-weight: bold;
      }
      .org-gnus-header-name {
        /* gnus-header-name-face */
        color: #00bfff;
      }
      .org-gnus-header-newsgroups {
        /* gnus-header-newsgroups-face */
        color: #a020f0;
        font-weight: bold;
        font-style: italic;
      }
      .org-gnus-header-subject {
        /* gnus-header-subject-face */
        color: #ffa500;
        font-weight: bold;
      }
      .org-gnus-signature {
        /* gnus-signature-face */
        color: #f0e68c;
        font-weight: bold;
      }
      .org-gnus-splash {
        /* gnus-splash */
        color: #a52a2a;
      }
      .org-gnus-summary-cancelled {
        /* gnus-summary-cancelled */
        color: #ffff00;
        background-color: #000000;
      }
      .org-gnus-summary-high-ancient {
        /* gnus-summary-high-ancient */
        color: #87ceeb;
        font-weight: bold;
      }
      .org-gnus-summary-high-read {
        /* gnus-summary-high-read */
        color: #98fb98;
        font-weight: bold;
      }
      .org-gnus-summary-high-ticked {
        /* gnus-summary-high-ticked */
        color: #ffc0cb;
        font-weight: bold;
      }
      .org-gnus-summary-high-undownloaded {
        /* gnus-summary-high-undownloaded */
        color: #d3d3d3;
        font-weight: bold;
      }
      .org-gnus-summary-high-unread {
        /* gnus-summary-high-unread */
        font-weight: bold;
      }
      .org-gnus-summary-low-ancient {
        /* gnus-summary-low-ancient */
        color: #87ceeb;
        font-style: italic;
      }
      .org-gnus-summary-low-read {
        /* gnus-summary-low-read */
        color: #98fb98;
        font-style: italic;
      }
      .org-gnus-summary-low-ticked {
        /* gnus-summary-low-ticked */
        color: #ffc0cb;
        font-style: italic;
      }
      .org-gnus-summary-low-undownloaded {
        /* gnus-summary-low-undownloaded */
        color: #d3d3d3;
        font-style: italic;
      }
      .org-gnus-summary-low-unread {
        /* gnus-summary-low-unread */
        font-style: italic;
      }
      .org-gnus-summary-normal-ancient {
        /* gnus-summary-normal-ancient */
        color: #87ceeb;
      }
      .org-gnus-summary-normal-read {
        /* gnus-summary-normal-read */
        color: #98fb98;
      }
      .org-gnus-summary-normal-ticked {
        /* gnus-summary-normal-ticked */
        color: #ffc0cb;
      }
      .org-gnus-summary-normal-undownloaded {
        /* gnus-summary-normal-undownloaded */
        color: #d3d3d3;
      }
      .org-gnus-summary-normal-unread {
      }
      .org-gnus-summary-selected {
        /* gnus-summary-selected */
        text-decoration: underline;
      }
      .org-gui-element {
        /* gui-element */
        color: #000000;
        background-color: #D4D0C8;
      }
      .org-header-line {
        /* header-line */
        color: #e5e5e5;
        background-color: #333333;
      }
      .org-help-argument-name {
      }
      .org-hi-mumamo-black-b {
        /* hi-mumamo-black-b */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-hi-mumamo-blue {
        /* hi-mumamo-blue */
        text-decoration: underline;
      }
      .org-hi-mumamo-blue-b {
        /* hi-mumamo-blue-b */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-hi-mumamo-green {
        /* hi-mumamo-green */
        text-decoration: underline;
      }
      .org-hi-mumamo-green-b {
        /* hi-mumamo-green-b */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-hi-mumamo-pink {
        /* hi-mumamo-pink */
        text-decoration: underline;
      }
      .org-hi-mumamo-red-b {
        /* hi-mumamo-red-b */
        font-weight: bold;
        text-decoration: underline;
      }
      .org-hi-mumamo-yellow {
        /* hi-mumamo-yellow */
        text-decoration: underline;
      }
      .org-highlight {
        /* highlight */
        background-color: #111111;
      }
      .org-highline {
        /* highline-face */
        background-color: #2e8b57;
      }
      .org-holiday {
        /* holiday */
        background-color: #8b4513;
      }
      .org-ido-first-match {
        /* ido-first-match */
        color: #8F9D6A;
      }
      .org-ido-incomplete-regexp {
        /* ido-incomplete-regexp */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-ido-indicator {
        /* ido-indicator */
        color: #ffff00;
        background-color: #ff0000;
      }
      .org-ido-only-match {
        /* ido-only-match */
        color: #8F9D6A;
      }
      .org-ido-subdir {
        /* ido-subdir */
        color: #CF6A4C;
      }
      .org-info-header-node {
        /* info-header-node */
        color: #ffffff;
        font-weight: bold;
        font-style: italic;
      }
      .org-info-header-xref {
        /* info-header-xref */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-info-menu-header {
        /* info-menu-header */
        font-weight: bold;
      }
      .org-info-menu-star {
        /* info-menu-star */
        color: #ff0000;
      }
      .org-info-node {
        /* info-node */
        color: #ffffff;
        font-weight: bold;
        font-style: italic;
      }
      .org-info-title-1 {
        /* info-title-1 */
        font-size: 172%;
        font-weight: bold;
      }
      .org-info-title-2 {
        /* info-title-2 */
        font-size: 144%;
        font-weight: bold;
      }
      .org-info-title-3 {
        /* info-title-3 */
        font-size: 120%;
        font-weight: bold;
      }
      .org-info-title-4 {
        /* info-title-4 */
        font-weight: bold;
      }
      .org-info-xref {
        /* info-xref */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-isearch {
        /* isearch */
        color: #8b2323;
        background-color: #0000ff;
      }
      .org-isearch-fail {
        /* isearch-fail */
        background-color: #8b0000;
      }
      .org-iswitchb-current-match {
        /* iswitchb-current-match */
        color: #9B703F;
      }
      .org-iswitchb-invalid-regexp {
        /* iswitchb-invalid-regexp */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-iswitchb-single-match {
        /* iswitchb-single-match */
        color: #5F5A60;
      }
      .org-iswitchb-virtual-matches {
        /* iswitchb-virtual-matches */
        color: #CACACA;
      }
      .org-italic {
        /* italic */
        font-style: italic;
        text-decoration: underline;
      }
      .org-keyword {
        /* font-lock-keyword-face */
        color: #CDA869;
      }
      .org-lazy-highlight {
        /* lazy-highlight */
        background-color: #668b8b;
      }
      .org-left-margin {
      }
      .org-link {
        /* link */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-link-visited {
        /* link-visited */
        color: #ee82ee;
        text-decoration: underline;
      }
      .org-match {
        /* match */
        background-color: #3a5fcd;
      }
      .org-menu {
      }
      .org-message-cited-text {
        /* message-cited-text */
        color: #ff0000;
        font-weight: bold;
      }
      .org-message-header-cc {
        /* message-header-cc */
        color: #008b00;
        font-weight: bold;
      }
      .org-message-header-name {
        /* message-header-name */
        color: #ffa500;
        font-weight: bold;
      }
      .org-message-header-newsgroups {
        /* message-header-newsgroups */
        color: #ee82ee;
        font-weight: bold;
      }
      .org-message-header-other {
        /* message-header-other */
        color: #d2691e;
        font-weight: bold;
      }
      .org-message-header-subject {
        /* message-header-subject */
        color: #ffff00;
        font-weight: bold;
      }
      .org-message-header-to {
        /* message-header-to */
        color: #00ffff;
        font-weight: bold;
      }
      .org-message-header-xheader {
        /* message-header-xheader */
        color: #add8e6;
        font-weight: bold;
      }
      .org-message-mml {
        /* message-mml */
        background-color: #00cd00;
        font-weight: bold;
      }
      .org-message-separator {
        /* message-separator */
        color: #0000cd;
      }
      .org-minibuffer-prompt {
        /* minibuffer-prompt */
        color: #5F5A60;
      }
      .org-mlinks-link {
        /* mlinks-link */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-mode-line {
        /* mode-line */
        color: #000000;
        background-color: #bfbfbf;
      }
      .org-mode-line-buffer-id {
        /* mode-line-buffer-id */
        color: #000000;
        background-color: #ffffff;
      }
      .org-mode-line-emphasis {
        /* mode-line-emphasis */
        font-weight: bold;
      }
      .org-mode-line-highlight {
      }
      .org-mode-line-inactive {
        /* mode-line-inactive */
        color: #cccccc;
        background-color: #4d4d4d;
      }
      .org-modeline-mousable {
        /* modeline-mousable */
        color: #000000;
        background-color: #ffffff;
      }
      .org-modeline-mousable-minor-mode {
        /* modeline-mousable-minor-mode */
        color: #000000;
        background-color: #ffffff;
      }
      .org-mouse {
        /* mouse */
        background-color: #ff8247;
      }
      .org-mumamo-background-chunk-major {
        /* mumamo-background-chunk-major */
        background-color: #191970;
      }
      .org-mumamo-background-chunk-submode {
        /* mumamo-background-chunk-submode */
        background-color: #222222;
      }
      .org-mumamo-background-chunk-submode1 {
        /* mumamo-background-chunk-submode1 */
        background-color: #006400;
      }
      .org-mumamo-background-chunk-submode2 {
        /* mumamo-background-chunk-submode2 */
        background-color: #006400;
      }
      .org-mumamo-background-chunk-submode3 {
        /* mumamo-background-chunk-submode3 */
        background-color: #006400;
      }
      .org-mumamo-background-chunk-submode4 {
        /* mumamo-background-chunk-submode4 */
        background-color: #006400;
      }
      .org-mumamo-border-face-in {
        /* mumamo-border-face-in */
        color: #7fffd4;
        font-weight: bold;
        font-style: italic;
        text-decoration: underline;
      }
      .org-mumamo-border-face-out {
        /* mumamo-border-face-out */
        color: #7fffd4;
        font-weight: bold;
        font-style: italic;
      }
      .org-negation-char {
      }
      .org-next-error {
        /* next-error */
        background-color: #27292A;
      }
      .org-nobreak-space {
        /* nobreak-space */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-nxml-attribute-colon {
      }
      .org-nxml-attribute-local-name {
        /* nxml-attribute-local-name */
        color: #7587A6;
      }
      .org-nxml-attribute-prefix {
        /* nxml-attribute-prefix */
        color: #CACACA;
      }
      .org-nxml-attribute-value {
        /* nxml-attribute-value */
        color: #8F9D6A;
      }
      .org-nxml-attribute-value-delimiter {
        /* nxml-attribute-value-delimiter */
        color: #8F9D6A;
      }
      .org-nxml-cdata-section-cdata {
        /* nxml-cdata-section-CDATA */
        color: #CACACA;
      }
      .org-nxml-cdata-section-content {
      }
      .org-nxml-cdata-section-delimiter {
      }
      .org-nxml-char-ref-delimiter {
        /* nxml-char-ref-delimiter */
        color: #CF6A4C;
      }
      .org-nxml-char-ref-number {
        /* nxml-char-ref-number */
        color: #CF6A4C;
      }
      .org-nxml-comment-content {
        /* nxml-comment-content */
        color: #5F5A60;
      }
      .org-nxml-comment-delimiter {
        /* nxml-comment-delimiter */
        color: #5F5A60;
      }
      .org-nxml-delimited-data {
        /* nxml-delimited-data */
        color: #8F9D6A;
      }
      .org-nxml-delimiter {
      }
      .org-nxml-element-colon {
      }
      .org-nxml-element-local-name {
        /* nxml-element-local-name */
        color: #9B703F;
      }
      .org-nxml-element-prefix {
        /* nxml-element-prefix */
        color: #CACACA;
      }
      .org-nxml-entity-ref-delimiter {
        /* nxml-entity-ref-delimiter */
        color: #CF6A4C;
      }
      .org-nxml-entity-ref-name {
        /* nxml-entity-ref-name */
        color: #CF6A4C;
      }
      .org-nxml-glyph {
        /* nxml-glyph */
        color: #000000;
        background-color: #d3d3d3;
      }
      .org-nxml-hash {
        /* nxml-hash */
        color: #CACACA;
      }
      .org-nxml-heading {
        /* nxml-heading */
        font-weight: bold;
      }
      .org-nxml-markup-declaration-delimiter {
      }
      .org-nxml-name {
        /* nxml-name */
        color: #CACACA;
      }
      .org-nxml-namespace-attribute-colon {
      }
      .org-nxml-namespace-attribute-prefix {
        /* nxml-namespace-attribute-prefix */
        color: #7587A6;
      }
      .org-nxml-namespace-attribute-value {
        /* nxml-namespace-attribute-value */
        color: #8F9D6A;
      }
      .org-nxml-namespace-attribute-value-delimiter {
        /* nxml-namespace-attribute-value-delimiter */
        color: #8F9D6A;
      }
      .org-nxml-namespace-attribute-xmlns {
        /* nxml-namespace-attribute-xmlns */
        color: #CACACA;
      }
      .org-nxml-outline-active-indicator {
        /* nxml-outline-active-indicator */
        color: #F8F8F8;
        background-color: #141414;
      }
      .org-nxml-outline-ellipsis {
        /* nxml-outline-ellipsis */
        color: #F8F8F8;
        background-color: #141414;
        font-weight: bold;
      }
      .org-nxml-outline-indicator {
        /* nxml-outline-indicator */
        color: #F8F8F8;
        background-color: #141414;
      }
      .org-nxml-processing-instruction-content {
        /* nxml-processing-instruction-content */
        color: #8F9D6A;
      }
      .org-nxml-processing-instruction-delimiter {
      }
      .org-nxml-processing-instruction-target {
        /* nxml-processing-instruction-target */
        color: #CDA869;
      }
      .org-nxml-prolog-keyword {
        /* nxml-prolog-keyword */
        color: #CDA869;
      }
      .org-nxml-prolog-literal-content {
        /* nxml-prolog-literal-content */
        color: #8F9D6A;
      }
      .org-nxml-prolog-literal-delimiter {
        /* nxml-prolog-literal-delimiter */
        color: #8F9D6A;
      }
      .org-nxml-ref {
        /* nxml-ref */
        color: #CF6A4C;
      }
      .org-nxml-tag-delimiter {
      }
      .org-nxml-tag-slash {
      }
      .org-nxml-text {
      }
      .org-org-agenda-column-dateline {
        /* org-agenda-column-dateline */
        background-color: #4d4d4d;
      }
      .org-org-agenda-date {
      }
      .org-org-agenda-date-today {
        /* org-agenda-date-today */
        font-weight: bold;
        font-style: italic;
      }
      .org-org-agenda-date-weekend {
        /* org-agenda-date-weekend */
        font-weight: bold;
      }
      .org-org-agenda-dimmed-todo {
        /* org-agenda-dimmed-todo-face */
        color: #7f7f7f;
      }
      .org-org-agenda-done {
        /* org-agenda-done */
        color: #98fb98;
      }
      .org-org-agenda-restriction-lock {
        /* org-agenda-restriction-lock */
        background-color: #4a708b;
      }
      .org-org-agenda-structure {
        /* org-agenda-structure */
        color: #87cefa;
      }
      .org-org-archived {
        /* org-archived */
        color: #b3b3b3;
      }
      .org-org-block {
        /* org-block */
        color: #b3b3b3;
      }
      .org-org-checkbox {
        /* org-checkbox */
        font-weight: bold;
      }
      .org-org-checkbox-statistics-done {
      }
      .org-org-checkbox-statistics-todo {
      }
      .org-org-clock-overlay {
        /* org-clock-overlay */
        background-color: #4a708b;
      }
      .org-org-code {
        /* org-code */
        color: #b3b3b3;
      }
      .org-org-column {
        /* org-column */
        background-color: #4d4d4d;
      }
      .org-org-column-title {
        /* org-column-title */
        background-color: #4d4d4d;
        font-weight: bold;
        text-decoration: underline;
      }
      .org-org-date {
        /* org-date */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-org-done {
        /* org-done */
        color: #98fb98;
        font-weight: bold;
      }
      .org-org-drawer {
        /* org-drawer */
        color: #87cefa;
      }
      .org-org-ellipsis {
        /* org-ellipsis */
        color: #eedd82;
        text-decoration: underline;
      }
      .org-org-eval {
        /* org-eval */
        color: #999999;
      }
      .org-org-footnote {
        /* org-footnote */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-org-formula {
        /* org-formula */
        color: #ff7f24;
      }
      .org-org-headline-done {
        /* org-headline-done */
        color: #ffa07a;
      }
      .org-org-hide {
        /* org-hide */
        color: #000000;
      }
      .org-org-latex-and-export-specials {
        /* org-latex-and-export-specials */
        color: #deb887;
      }
      .org-org-level-1 {
        /* org-level-1 */
        color: #9B703F;
      }
      .org-org-level-2 {
        /* org-level-2 */
        color: #7587A6;
      }
      .org-org-level-3 {
        /* org-level-3 */
        color: #CDA869;
      }
      .org-org-level-4 {
        /* org-level-4 */
        color: #5F5A60;
      }
      .org-org-level-5 {
        /* org-level-5 */
        color: #9B703F;
      }
      .org-org-level-6 {
        /* org-level-6 */
        color: #CF6A4C;
      }
      .org-org-level-7 {
        /* org-level-7 */
        color: #CACACA;
      }
      .org-org-level-8 {
        /* org-level-8 */
        color: #8F9D6A;
      }
      .org-org-link {
        /* org-link */
        color: #00ffff;
        text-decoration: underline;
      }
      .org-org-meta-line {
        /* org-meta-line */
        color: #5F5A60;
      }
      .org-org-mode-line-clock {
      }
      .org-org-mtags {
        /* org-mtags */
        color: #b3b3b3;
      }
      .org-org-property-value {
      }
      .org-org-scheduled {
        /* org-scheduled */
        color: #98fb98;
      }
      .org-org-scheduled-previously {
        /* org-scheduled-previously */
        color: #ff7f24;
      }
      .org-org-scheduled-today {
        /* org-scheduled-today */
        color: #98fb98;
      }
      .org-org-sexp-date {
        /* org-sexp-date */
        color: #00ffff;
      }
      .org-org-special-keyword {
        /* org-special-keyword */
        color: #ffa07a;
      }
      .org-org-table {
        /* org-table */
        color: #87cefa;
      }
      .org-org-tag {
        /* org-tag */
        font-weight: bold;
      }
      .org-org-target {
        /* org-target */
        text-decoration: underline;
      }
      .org-org-time-grid {
        /* org-time-grid */
        color: #eedd82;
      }
      .org-org-todo {
        /* org-todo */
        color: #ffc0cb;
        font-weight: bold;
      }
      .org-org-upcoming-deadline {
        /* org-upcoming-deadline */
        color: #ff7f24;
      }
      .org-org-verbatim {
        /* org-verbatim */
        color: #b3b3b3;
      }
      .org-org-warning {
        /* org-warning */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-orgpan-spaceline {
        /* orgpan-spaceline */
        font-size: 20%;
      }
      .org-outline-1 {
        /* outline-1 */
        color: #9B703F;
      }
      .org-outline-2 {
        /* outline-2 */
        color: #7587A6;
      }
      .org-outline-3 {
        /* outline-3 */
        color: #CDA869;
      }
      .org-outline-4 {
        /* outline-4 */
        color: #5F5A60;
      }
      .org-outline-5 {
        /* outline-5 */
        color: #9B703F;
      }
      .org-outline-6 {
        /* outline-6 */
        color: #CF6A4C;
      }
      .org-outline-7 {
        /* outline-7 */
        color: #CACACA;
      }
      .org-outline-8 {
        /* outline-8 */
        color: #8F9D6A;
      }
      .org-preprocessor {
        /* font-lock-preprocessor-face */
        color: #7fffd4;
      }
      .org-primary-selection {
        /* primary-selection */
        background-color: #0000ff;
      }
      .org-query-replace {
        /* query-replace */
        color: #8b2323;
        background-color: #0000ff;
      }
      .org-reference {
        /* font-lock-reference-face */
        color: #6a5acd;
      }
      .org-regexp-grouping-backslash {
        /* font-lock-regexp-grouping-backslash */
        color: #E9C062;
      }
      .org-regexp-grouping-construct {
        /* font-lock-regexp-grouping-construct */
        color: #ff0000;
      }
      .org-region {
        /* region */
        background-color: #27292A;
      }
      .org-rng-error {
        /* rng-error */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-rngalt-validation-header-bottom {
        /* rngalt-validation-header-bottom */
        color: #ffffff;
        background-color: #87cefa;
      }
      .org-rngalt-validation-header-top {
        /* rngalt-validation-header-top */
        color: #87cefa;
        background-color: #ffffff;
      }
      .org-scroll-bar {
      }
      .org-secondary-selection {
        /* secondary-selection */
        background-color: #483d8b;
      }
      .org-sgml-namespace {
        /* sgml-namespace */
        color: #CACACA;
      }
      .org-sh-escaped-newline {
        /* sh-escaped-newline */
        color: #8F9D6A;
      }
      .org-sh-heredoc {
        /* sh-heredoc */
        color: #ffff00;
        font-weight: bold;
      }
      .org-sh-quoted-exec {
        /* sh-quoted-exec */
        color: #fa8072;
      }
      .org-shadow {
        /* shadow */
        color: #b3b3b3;
      }
      .org-speedbar-button {
        /* speedbar-button-face */
        color: #00cd00;
      }
      .org-speedbar-directory {
        /* speedbar-directory-face */
        color: #add8e6;
      }
      .org-speedbar-file {
        /* speedbar-file-face */
        color: #00ffff;
      }
      .org-speedbar-highlight {
        /* speedbar-highlight-face */
        background-color: #2e8b57;
      }
      .org-speedbar-selected {
        /* speedbar-selected-face */
        color: #ff0000;
        text-decoration: underline;
      }
      .org-speedbar-separator {
        /* speedbar-separator-face */
        color: #ffffff;
        background-color: #0000ff;
        text-decoration: overline;
      }
      .org-speedbar-tag {
        /* speedbar-tag-face */
        color: #ffff00;
      }
      .org-string {
        /* font-lock-string-face */
        color: #8F9D6A;
      }
      .org-text-cursor {
        /* text-cursor */
        color: #000000;
        background-color: #ffff00;
      }
      .org-tool-bar {
      }
      .org-tooltip {
        /* tooltip */
        color: #000000;
        background-color: #ffffe0;
      }
      .org-trailing-whitespace {
        /* trailing-whitespace */
        background-color: #ff0000;
      }
      .org-type {
        /* font-lock-type-face */
        color: #9B703F;
      }
      .org-underline {
      }
      .org-variable-name {
        /* font-lock-variable-name-face */
        color: #7587A6;
      }
      .org-variable-pitch {
      }
      .org-vertical-border {
      }
      .org-warning {
        /* font-lock-warning-face */
        color: #ff0000;
        background-color: #EE799F;
        font-weight: bold;
      }
      .org-widget-button {
        /* widget-button */
        font-weight: bold;
      }
      .org-widget-button-pressed {
        /* widget-button-pressed */
        color: #ff0000;
      }
      .org-widget-documentation {
        /* widget-documentation */
        color: #32cd32;
      }
      .org-widget-field {
        /* widget-field */
        background-color: #696969;
      }
      .org-widget-inactive {
        /* widget-inactive */
        color: #d3d3d3;
      }
      .org-widget-single-line-field {
        /* widget-single-line-field */
        background-color: #696969;
      }
      .org-zmacs-region {
        /* zmacs-region */
        color: #0000ff;
        background-color: #fffafa;
      }

      a {
        color: inherit;
        background-color: inherit;
        font: inherit;
        text-decoration: inherit;
      }
      a:hover {
        text-decoration: underline;
      }
