  <footer>
    <hr />

    {if DYNE_DEBUG_RENDERING_TIME}
    <section id="dyne_debug">
      <p>Page Rendering Time: {$timer->stop()}ms.</p>
    </section>
    {/if}

    <section id="disclaimer">
      <h2>dyne.org</h2>
      <p>
        Copyleft 2000 - 2010 dyne.org foundation and respective authors. 
	Verbatim copying and distribution is permitted in any medium, 
	provided this notice is preserved.
	<p><a href="contact">Send your enquiries &amp; questions to dyne's hackers</a>.</p>
      </p>
    </section>

    <section id="recognition">
      <h2>Recognition</h2>
      <ul>
        <li><a href="http://www.gnu.org/"><img src="http://dyne.org/images/badges/gnu_75x65.png" alt="Dyne:bolic is listed on the GNU Free Distro page"/></a></li>
        <li><a href="http://www.unesco.org/cgi-bin/webworld/portal_freesoftware/cgi/page.cgi?g=Information/Initiatives/index.shtml&d=1"><img
            src="http://dyne.org/images/badges/listed-by-unesco_76x36.png" alt="Dyne and Freaknet are listed on the Unesco Archives portal since 2002"/></a></li>
      </ul>
    </section>

    <section id="badges">
      <h2>Internet Campains</h2>
      <ul>
        <li><a href="http://w2.eff.org/br/"><img src="http://dyne.org/images/badges/eff-blue-ribbon_80x15.png" alt="EFF Free Speech Campain"/></a></li>
        <li><a href="http://nosoftwarepatents.com/"><img src="http://dyne.org/images/badges/no-software-patents_80x15.png" alt="No Software Patents!"/></a></li>
        <li><a href="http://www.fsf.org/resources/formats/playogg"><img src="http://dyne.org/images/badges/play-ogg_80x15.png" alt="Play OGG"/></a></li>
        <li><a href="http://www.defectivebydesign.org/join/button"><img src="http://dyne.org/images/badges/no-drm_80x15.png" alt="Digital Rights Now!"/></a></li>
        <li><a href="http://code.dyne.org/"><img src="http://dyne.org/images/badges/dyne-software_80x15.png" alt="dyne.org software badge"/></a></li>
      </ul>
    </section>

    <section id="credits">
      <h2>Credits</h2>
      <p><a href="http://dyne.org/" target="_top"><img src="http://dyne.org/dyne-sm.png" alt="dyne.org stamp" /></a></p>
      <p>Dyne hosting is kindly provided by
      <a href="http://nimk.nl/">nimk.nl</a> 
      and
      <a href="http://servus.at/">servus.at</a></p>
      <p id="clustrMaps"></p>
    </section>

  </footer>
  <script type="text/javascript" src="http://www.google.com/jsapi"></script>
  <script type="text/javascript">google.load("jquery", "1.4.0");</script>
  <script type="text/javascript" src="/javascripts/dyne.js"></script>
</body>
</html>
