#gallery { 
           width: 100%;
           clear: right;
           }
#gallery h3 { 
     margin-left: 2em;
     }
#filter { 
          float: left;
          width: 50%;
          }
#parameters {               
              margin: 2em;
             }