body {
  background-color: #fed;
  color: #000;
  font-family: monospace;
  font-size: medium;
}

a { text-decoration: none }
a:link { color: #a60; }
a:visited { color: #840 }
a:hover,a:focus,a:active { text-decoration: underline }

#dyne_links {
  margin: 0 auto;
  padding: 0;
  list-style: none;
  text-align: center;
  font-size: larger;
  font-weight: bold;
}
#dyne_links li {
  display: inline;
}
#dyne_links li.org {
  font-size: medium;
  font-weight: normal;
}

header {
  background-color: #fed;
  position: fixed;
  left: 0;
  right: 0;
  z-index: 666;
}

header hgroup, section {
  position: absolute;
  left: 0;
  right: 0;
}
header hgroup, #intro {
  margin-left: 2.5%;
  margin-right: 70%
}
header hgroup p {
  margin: 5px
}
#intro {
  position: fixed;
  margin-top: 6em;
  text-align: center
}
#intro p { font-weight: bold; text-align: justify; line-height: 1.5em }
#intro img { }
#sites {
  margin-left:  35%;
  margin-right: 2.5%;  
  margin-top: 3em
}
#sites img {
  background-color: #fed;
  border: 24px solid #fed;
  margin: 0 3% 0 0;
  width: 48px;
  height: 48px;
  float: left
}

header hgroup {
  padding-top: 1em
}
header h1 {
  margin: 0
}


#sites dl {
  margin: 0
}
#software, #events {
  margin-top: 180px;
}
#software {
  margin-left: 35%;
  margin-right: 35%;
}
#events {
  margin-left: 70%;
}

.data { display: none }

footer {
  background-color: #fed;
  position: fixed;
  bottom: 0;
  padding: 0 10px;
  padding-bottom: 10px;
  left: 0; right: 0;
  font-size: smaller;
  height: 70px;
}
footer:hover,footer:focus {
  height: auto;
}
footer:hover section, footer:focus section,
footer:hover section h2, footer:focus section h2,
footer:hover #clustrMaps
{
  display: block
}

#self-promotion,#badges { width: 15% }

footer ul {
  list-style: none;
  margin: 0;
  padding: 0;
}  

footer section {
  position: relative;
  display: none;
  float: left;
  width: 33%;
}
footer section h2 { display: none }
#credits { display: block }
#clustrMaps { display: none }
footer section.copyright { display: block }